#include "BitmapMarkMenuItem.h"

BitmapMarkMenuItem::BitmapMarkMenuItem(const char *label, BMessage *message,
	BBitmap *bitmapOn, BBitmap *bitmapOff,
	char shortcut, uint32 modifiers)
	: BMenuItem(label, message, shortcut, modifiers),
		fOn(bitmapOn), fOff(bitmapOff)
{
}

BitmapMarkMenuItem::~BitmapMarkMenuItem()
{
	delete fOn;
	delete fOff;
}

void BitmapMarkMenuItem::SetBitmapOn(BBitmap *on)
{
	delete fOn;
	fOn = on;
}

void BitmapMarkMenuItem::SetBitmapOff(BBitmap *off)
{
	delete fOff;
	fOff = off;
}

void BitmapMarkMenuItem::Draw()
{
	BMenuItem::Draw();
	
	
	BRect contentRect;
	BPoint point = this->ContentLocation();
	contentRect.top = point.y;
	contentRect.left = point.x;
	float width, height;
	GetContentSize(&width, &height);
	contentRect.bottom = contentRect.top + height - 1;
	contentRect.right = contentRect.left + width - 1;
	
	BRect markRect = contentRect;
	markRect.right = markRect.left - 1;
	markRect.left = 0;
	
	BRect frame = markRect;
	rgb_color bgcolor;
	if (IsSelected())
		bgcolor = tint_color(ui_color(B_MENU_BACKGROUND_COLOR), B_HIGHLIGHT_BACKGROUND_TINT);
	else
		bgcolor = ui_color(B_MENU_BACKGROUND_COLOR);
	rgb_color old_color = Menu()->HighColor();
	Menu()->SetHighColor(bgcolor);
	Menu()->FillRect(frame);
	Menu()->SetHighColor(old_color);
	
	if (IsEnabled())
		Menu()->SetDrawingMode(B_OP_OVER);
	else
		Menu()->SetDrawingMode(B_OP_BLEND);
	
	if (IsMarked())
	{
		if (fOn != NULL)
			Menu()->DrawBitmap(fOn, frame.LeftTop());
	}
	else
	{
		if (fOff != NULL)
			Menu()->DrawBitmap(fOff, frame.LeftTop());
	}
}

